@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 github3.repos.contents
 ======================
@@ -6,12 +7,13 @@ This module contains the Contents object pertaining to READMEs and other files
 that can be accessed via the GitHub API.
 
 """
+from __future__ import unicode_literals
 
 from json import dumps
 from base64 import b64decode, b64encode
-from github3.git import Commit
-from github3.models import GitHubCore
-from github3.decorators import requires_auth
+from ..git import Commit
+from ..models import GitHubCore
+from ..decorators import requires_auth
 
 
 class Contents(GitHubCore):
@@ -80,11 +82,10 @@ class Contents(GitHubCore):
         #: points to
         self.target = content.get('target', '')
 
-    def __repr__(self):
-        return '<Content [{0}]>'.format(self.path)
+        self._uniq = self.sha
 
-    def __str__(self):
-        return self.decoded
+    def _repr(self):
+        return '<Content [{0}]>'.format(self.path)
 
     def __eq__(self, other):
         return self.decoded == other
@@ -93,10 +94,12 @@ class Contents(GitHubCore):
         return self.sha != other
 
     @requires_auth
-    def delete(self, message, committer=None, author=None):
+    def delete(self, message, branch=None, committer=None, author=None):
         """Delete this file.
 
         :param str message: (required), commit message to describe the removal
+        :param str branch: (optional), branch where the file exists.
+            Defaults to the default branch of the repository.
         :param dict committer: (optional), if no information is given the
             authenticated user's information will be used. You must specify
             both a name and email.
@@ -108,7 +111,7 @@ class Contents(GitHubCore):
         """
         json = None
         if message:
-            data = {'message': message, 'sha': self.sha,
+            data = {'message': message, 'sha': self.sha, 'branch': branch,
                     'committer': validate_commmitter(committer),
                     'author': validate_commmitter(author)}
             self._remove_none(data)
@@ -118,11 +121,14 @@ class Contents(GitHubCore):
         return json
 
     @requires_auth
-    def update(self, message, content, committer=None, author=None):
+    def update(self, message, content, branch=None, committer=None,
+               author=None):
         """Update this file.
 
         :param str message: (required), commit message to describe the update
         :param str content: (required), content to update the file with
+        :param str branch: (optional), branch where the file exists.
+            Defaults to the default branch of the repository.
         :param dict committer: (optional), if no information is given the
             authenticated user's information will be used. You must specify
             both a name and email.
@@ -139,7 +145,8 @@ class Contents(GitHubCore):
         json = None
         if message and content:
             content = b64encode(content).decode('utf-8')
-            data = {'message': message, 'content': content, 'sha': self.sha,
+            data = {'message': message, 'content': content, 'branch': branch,
+                    'sha': self.sha,
                     'committer': validate_commmitter(committer),
                     'author': validate_commmitter(author)}
             self._remove_none(data)
